<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class de_mach_archive_loop_code extends ET_Builder_Module {

    public $vb_support = 'on';

    protected $module_credits = array(
      'module_uri' => DE_DMACH_PRODUCT_URL,
      'author'     => DE_DMACH_AUTHOR,
      'author_uri' => DE_DMACH_URL,
    );

    function init() {
        $this->name       = esc_html__( '.Archive Loop - Divi Machine', 'divi-machine' );
        $this->slug = 'et_pb_de_mach_archive_loop';


        $this->fields_defaults = array(
        // 'loop_layout'         => array( 'on' ),
        );

        $this->settings_modal_toggles = array(
            'general' => array(
            	'toggles' => array(
            		'main_content' => esc_html__( 'Main Options', 'divi-machine' ),
            		'loop_options' => esc_html__( 'Loop Options', 'divi-machine' ),
            		'element_options' => esc_html__( 'Element Options', 'divi-machine' ),
            		'grid_options' => esc_html__( 'Grid Options', 'divi-machine' ),
            		'extra_options' => esc_html__( 'Extra Options', 'divi-machine' ),
            	),
            ),
            'advanced' => array(
            	'toggles' => array(
                       'alignment'  => esc_html__( 'Alignment', 'et_builder' ),
            		'text' => esc_html__( 'Text', 'divi-machine' ),
                  'overlay' => esc_html__( 'Overlay', 'divi-machine' ),
            	),
            ),
        );


        $this->main_css_element = '%%order_class%%';


        $this->advanced_fields = array(
            'fonts' => array(
            	'title' => array(
            		'label'    => esc_html__( 'Default Layout - Title', 'divi-machine' ),
            		'css'      => array(
            			'main' => "%%order_class%% ul.products li.product .woocommerce-loop-product__title",
            			'important' => 'plugin_only',
            		),
            		'font_size' => array(
            			'default' => '14px',
            		),
            		'line_height' => array(
            			'default' => '1em',
            		),
            	),
            	'excerpt' => array(
            		'label'    => esc_html__( 'Default Layout - Excerpt', 'divi-machine' ),
            		'css'      => array(
            			'main' => "%%order_class%% ul.products li.product .woocommerce-product-details__short-description",
            			'important' => 'plugin_only',
            		),
            		'font_size' => array(
            			'default' => '14px',
            		),
            		'line_height' => array(
            			'default' => '1em',
            		),
            	),
            ),
        	'background' => array(
        		'settings' => array(
        			'color' => 'alpha',
        		),
        	),
            'button' => array(
                'button' => array(
                    'label' => esc_html__( 'Button - Load More', 'divi-bodyshop-woocommerce' ),
                    'css' => array(
                        'main' => "{$this->main_css_element} .et_pb_button.dmach-loadmore",
                        'important' => 'all',
                    ),
                    'box_shadow'  => array(
                        'css' => array(
                            'main' => "{$this->main_css_element} .et_pb_button.dmach-loadmore",
                            'important' => 'all',
                        ),
                    ),
                    'margin_padding' => array(
                        'css'           => array(
                            'main' => "{$this->main_css_element} .et_pb_button.dmach-loadmore",
                            'important' => 'all',
                        ),
                    ),
                ),
            ),
            'box_shadow' => array(
            	'default' => array(),
            	'product' => array(
            		'label' => esc_html__( 'Default Layout - Box Shadow', 'divi-machine' ),
            		'css' => array(
            			'main' => "%%order_class%% .products .product",
            		),
            		'option_category' => 'layout',
            		'tab_slug'        => 'advanced',
            		'toggle_slug'     => 'product',
            	),
            ),
        );


        $this->custom_css_fields = array(
            'image' => array(
            	'label'    => esc_html__( 'Default Layout - Image', 'divi-machine' ),
            	'selector' => '%%order_class%% .et_shop_image',
            ),
            'overlay' => array(
            	'label'    => esc_html__( 'Default Layout - Overlay', 'divi-machine' ),
            	'selector' => '%%order_class%% .et_overlay,  %%order_class%% .et_pb_extra_overlay',
            ),
            'title' => array(
            	'label'    => esc_html__( 'Default Layout - Title', 'divi-machine' ),
            	'selector' => '%%order_class%% .woocommerce-loop-product__title',
            ),
        );


        $this->help_videos = array(
        );
    }

    function get_fields() {

        $options = array();

        $layout_query = array(
            'post_type'=>'et_pb_layout',
            'posts_per_page'=>-1,
            'meta_query' => array(
                array(
                    'key' => '_et_pb_predefined_layout',
                    'compare' => 'NOT EXISTS',
                ),
            )
        );
        $options['none'] = 'No Layout (please choose one)';
        if ($layouts = get_posts($layout_query)) {
            foreach ($layouts as $layout) {
                $options[$layout->ID] = $layout->post_title;
            }
        }

        ///////////////////////////////

        $acf_fields = DEDMACH_INIT::get_acf_fields();

        //////////////////////////////
        $fields = array(
            'post_type_choose' => array(
                'toggle_slug'       => 'main_content',
                'label'             => esc_html__( 'Post Type', 'divi-machine' ),
                'type'              => 'select',
        		'options'           => et_get_registered_post_type_options( false, false ),
                'option_category'   => 'configuration',
                'default'           => 'post',
                'computed_affects' => array(
                  '__getarchiveloop',
                ),
                'description'       => esc_html__( 'Choose the post type you want to display', 'divi-machine' ),
            ),
            'loop_layout' => array(
                'toggle_slug'       => 'main_content',
                'label'             => esc_html__( 'Custom Loop Layout', 'divi-machine' ),
                'type'              => 'select',
                'option_category'   => 'configuration',
                'default'           => 'none',
                'computed_affects' => array(
                  '__getarchiveloop',
                ),
                'options'           => $options,
                'description'        => esc_html__( 'Choose the layout you have made for each post in the loop.', 'divi-machine' ),
            ),
            'filter_update_animation' => array(
                'toggle_slug'       => 'main_content',
                'label'             => esc_html__( 'Filter Update Animation Style', 'divi-machine' ),
                'type'              => 'select',
                'options'           => array(
                    'load-1'       => esc_html__( 'Three Lines Vertical', 'divi-machine' ),
                    'load-2'       => esc_html__( 'Three Lines Horizontal', 'divi-machine' ),
                    'load-3'       => esc_html__( 'Three Dots Bouncing', 'divi-machine' ),
                    'load-4'       => esc_html__( 'Donut', 'divi-machine' ),
                    'load-5'       => esc_html__( 'Donut Multiple', 'divi-machine' ),
                    'load-6'       => esc_html__( 'Ripple', 'divi-machine' ),
                ),
                'option_category'   => 'configuration',
                'default'           => 'load-6',
                'description'       => esc_html__( 'Choose the animation style for when loading the posts', 'divi-machine' ),
            ),
            'animation_color' => array(
                'label'             => esc_html__( 'Animation Icon Color', 'et_builder' ),
                'description'       => esc_html__( 'Define the color of the animation you choose above.', 'et_builder' ),
                'type'              => 'color-alpha',
                'custom_color'      => true,
                'option_category'   => 'configuration',
                'toggle_slug'       => 'main_content',
            ),
            'no_posts_layout' => array(
                'toggle_slug'       => 'main_content',
                'label'             => esc_html__( 'No Posts Layout', 'divi-machine' ),
                'type'              => 'select',
                'option_category'   => 'configuration',
                'default'           => 'none',
                'options'           => $options,
                'description'        => esc_html__( 'Choose the layout that will be shown if there are no posts in the selection.', 'divi-machine' ),
            ),
            // LOOP SETTINGS
            'post_status' => array(
                'toggle_slug'       => 'loop_options',
                'option_category'   => 'configuration',
                'label'             => esc_html__( 'Post Status', 'divi-machine' ),
                'type'              => 'select',
                'options'           => array(
                    'publish' => sprintf( esc_html__( 'Publish', 'divi-machine' ) ),
                    'pending' => esc_html__( 'Pending', 'divi-machine' ),
                    'draft' => esc_html__( 'Draft', 'divi-machine' ),
                    'auto-draft' => esc_html__( 'Auto-draft', 'divi-machine' ),
                    'future' => esc_html__( 'Future', 'divi-machine' ),
                    'private' => esc_html__( 'Private', 'divi-machine' ),
                    'inherit' => esc_html__( 'Inherit', 'divi-machine' ),
                ),
                'default' => 'publish',
                'computed_affects' => array(
                  '__getarchiveloop',
                ),
                'description'       => esc_html__( 'Choose the status of the posts you want to show.', 'divi-machine' ),
            ),
            'posts_number' => array(
                'toggle_slug'       => 'loop_options',
                'option_category'   => 'configuration',
                'label'             => esc_html__( 'Post Count', 'divi-machine' ),
                'type'              => 'text',
                'default'           => 10,
                'computed_affects' => array(
                  '__getarchiveloop',
                ),
                'description'       => esc_html__( 'Choose how many posts you would like to display per page."', 'divi-machine' ),
            ),
            'include_cats' => array(
                'toggle_slug'       => 'loop_options',
                'option_category'   => 'configuration',
                'label'           => esc_html__( 'Include Categories (comma-seperated)', 'divi-machine' ),
                'type'            => 'text',
                'computed_affects' => array(
                  '__getarchiveloop',
                ),
                'description'     => esc_html__( 'Add a list of categories you want to include to show. This will remove all products that dont have these tags. (comma-seperated)', 'divi-machine' ),
            ),
            'include_tags' => array(
                'toggle_slug'       => 'loop_options',
                'option_category'   => 'configuration',
                'label'           => esc_html__( 'Include Tags (comma-seperated)', 'divi-machine' ),
                'type'            => 'text',
                'computed_affects' => array(
                  '__getarchiveloop',
                ),
                'description'     => esc_html__( 'Add a list of tags that you want to include to show. This will remove all products that dont have these tags. (comma-seperated)', 'divi-machine' ),
            ),
            'acf_name' => array(
                'toggle_slug'       => 'loop_options',
                'label'             => esc_html__( 'Filter By ACF Name', 'divi-machine' ),
                'type'              => 'select',
                'options'           => $acf_fields,
                'default'           => 'none',
                'option_category'   => 'configuration',
                'computed_affects' => array(
                  '__getarchiveloop',
                ),
                'description'       => esc_html__( 'Filter by this ACF name and then the value below', 'divi-machine' ),
            ),
            'acf_value' => array(
                'toggle_slug'       => 'loop_options',
                'option_category'   => 'configuration',
                'label'           => esc_html__( 'ACF Value', 'divi-machine' ),
                'type'            => 'text',
                'computed_affects' => array(
                  '__getarchiveloop',
                ),
                'description'     => esc_html__( 'Add the value here, it will show posts only with the value of the ACF field above', 'divi-machine' ),
            ),
            // 'author' => array(
            // 'toggle_slug'       => 'loop_options',
            // 'option_category'   => 'configuration',
            //   'label'           => esc_html__( 'Author/s (comma-seperated)', 'divi-machine' ),
            //   'type'            => 'text',
            //   'description'     => esc_html__( 'Add a list of authors IDs. (comma-seperated)', 'divi-machine' ),
            // ),
            'sort_order' => array(
                'toggle_slug'       => 'loop_options',
                'option_category'   => 'configuration',
                'label'             => esc_html__( 'Sort Order', 'divi-machine' ),
                'type'              => 'select',
                'options'           => array(
                    'date' => sprintf( esc_html__( 'Date', 'divi-machine' ) ),
                    'title' => esc_html__( 'Title', 'divi-machine' ),
                    'ID' => esc_html__( 'ID', 'divi-machine' ),
                    'rand' => esc_html__( 'Random', 'divi-machine' ),
                    'menu_order' => esc_html__( 'Menu Order', 'divi-machine' ),
                    'name' => esc_html__( 'Name', 'divi-machine' ),
                    'modified' => esc_html__( 'Modified', 'divi-machine' ),
                ),
                'default' => 'date',
                'computed_affects' => array(
                  '__getarchiveloop',
                ),
                'description'       => esc_html__( 'Choose the sort order of the products.', 'divi-machine' ),
            ),
            'order_asc_desc' => array(
                'toggle_slug'       => 'loop_options',
                'option_category'   => 'configuration',
                'label'             => esc_html__( 'Order', 'divi-machine' ),
                'type'              => 'select',
                'options'           => array(
                    'ASC' => esc_html__( 'Ascending', 'divi-machine' ),
                    'DESC' => sprintf( esc_html__( 'Descending', 'divi-machine' ) ),
                ),
                'default' => 'ASC',
                'computed_affects' => array(
                  '__getarchiveloop',
                ),
                'description'       => esc_html__( 'Choose the sort order of the products.', 'divi-machine' ),
            ),
            // ELEMENT SETTINGS
            'enable_loadmore' => array(
                'label'             => esc_html__( 'Enable Load More', 'divi-machine' ),
                'type'              => 'yes_no_button',
                'option_category'   => 'configuration',
                'options'           => array(
                    'on'  => esc_html__( 'Yes', 'divi-machine' ),
                    'off' => esc_html__( 'No', 'divi-machine' ),
                ),
                'description'       => esc_html__( 'If you want to have a button that loads more posts by clicking it (works only on archive pages and not on a custom home page or similar) - enable this.', 'divi-machine' ),
                'affects'         => array(
                    'loadmore_text',
                    'loadmore_text_loading',
                ),
                'default' => 'off',
                'toggle_slug'       => 'element_options',
            ),
            'loadmore_text' => array(
                'toggle_slug'       => 'element_options',
                'option_category'   => 'configuration',
                'label'           => esc_html__( 'Load More Text', 'divi-machine' ),
                'type'            => 'text',
                'depends_show_if' => 'on',
                'default' => 'Load More',
                'description'     => esc_html__( 'Add the text for the load more button', 'divi-machine' ),
            ),
            'loadmore_text_loading' => array(
                'toggle_slug'       => 'element_options',
                'option_category'   => 'configuration',
                'label'           => esc_html__( 'Load More Loading Text', 'divi-machine' ),
                'type'            => 'text',
                'depends_show_if' => 'on',
                'default' => 'Loading...',
                'description'     => esc_html__( 'Add the text for the load more button when it is loading', 'divi-machine' ),
            ),
            // ADVANCED OPTIONS
            'link_whole_gird' => array(
                'toggle_slug'       => 'extra_options',
                'label'             => esc_html__( 'Link each layout to single page', 'divi-machine' ),
                'type'              => 'yes_no_button',
                'options'           => array(
                    'off' => esc_html__( 'No', 'divi-machine' ),
                    'on'  => esc_html__( 'Yes', 'divi-machine' ),
                ),
                'description'        => esc_html__( 'Enable this if you want to link each loop layout to the product. For example if you want the whole "grid card" to link to the product page. NB: You need to have no other links on the loop layout so do not link the image or the title to the product page.', 'divi-machine' ),
            ),
            'grid_layout' => array(
                'toggle_slug'       => 'grid_options',
                'label'             => esc_html__( 'Grid Style', 'divi-machine' ),
                'type'              => 'select',
                'options'           => array(
                    'grid'       => esc_html__( 'Grid', 'divi-machine' ),
                    'masonry'       => esc_html__( 'Masonry', 'divi-machine' ),
                ),
                'affects'         => array(
                    'equal_height',
                    'align_last_bottom',
                ),
                'option_category'   => 'configuration',
                'default'           => 'grid',
                'description'       => esc_html__( 'Choose how you want your posts to be shown', 'divi-machine' ),
            ),

            'equal_height' => array(
                'label'             => esc_html__( 'Equal Height Grid Cards', 'divi-machine' ),
                'type'              => 'yes_no_button',
                'option_category'   => 'configuration',
                'depends_show_if' => 'grid',
                'options'           => array(
                    'on'  => esc_html__( 'Yes', 'divi-machine' ),
                    'off' => esc_html__( 'No', 'divi-machine' ),
                ),
                'description' => esc_html__( 'Enable this if you have the grid layout and want all your cards to be the same height.', 'divi-machine' ),
                'toggle_slug'       => 'grid_options',
            ),
            'align_last_bottom' => array(
                'toggle_slug'       => 'grid_options',
                'label'             => esc_html__( 'Align last module at the bottom', 'divi-machine' ),
                'type'              => 'yes_no_button',
                'depends_show_if' => 'grid',
                'options'           => array(
                    'off' => esc_html__( 'No', 'divi-machine' ),
                    'on'  => esc_html__( 'Yes', 'divi-machine' ),
                ),
                'description'        => esc_html__( 'Enable this to align the last module (probably the add to cart) at the bottom. Works well when using the equal height.', 'divi-machine' ),
            ),

            'columns' => array(
                'toggle_slug'       => 'grid_options',
                'label'             => esc_html__( 'Grid Columns', 'divi-machine' ),
                'type'              => 'select',
                'option_category'   => 'layout',
                'default'   => '4',
                'options'           => array(
                    '1'  => esc_html__( 'One', 'divi-machine' ),
                    '2'  => esc_html__( 'Two', 'divi-machine' ),
                    '3' => esc_html__( 'Three', 'divi-machine' ),
                    '4' => esc_html__( 'Four', 'divi-machine' ),
                    '5' => esc_html__( 'Five', 'divi-machine' ),
                    '6' => esc_html__( 'Six', 'divi-machine' ),
                ),
                'depends_show_if' => 'on',
                'computed_affects' => array(
                  '__getarchiveloop',
                ),
                'description'        => esc_html__( 'How many columns do you want to see', 'divi-machine' ),
            ),
            'columns_tablet' => array(
                'toggle_slug'       => 'grid_options',
                'label'             => esc_html__( 'Tablet Grid Columns', 'divi-machine' ),
                'type'              => 'select',
                'option_category'   => 'layout',
                'default'   => '2',
                'options'           => array(
                    1  => esc_html__( 'One', 'divi-machine' ),
                    2  => esc_html__( 'Two', 'divi-machine' ),
                    3 => esc_html__( 'Three', 'divi-machine' ),
                    4 => esc_html__( 'Four', 'divi-machine' ),
                ),
                'depends_show_if' => 'on',
                'computed_affects' => array(
                  '__getarchiveloop',
                ),
                'description'        => esc_html__( 'How many columns do you want to see on tablet', 'divi-machine' ),
            ),
            'columns_mobile' => array(
                'toggle_slug'       => 'grid_options',
                'label'             => esc_html__( 'Mobile Grid Columns', 'divi-machine' ),
                'type'              => 'select',
                'option_category'   => 'layout',
                'default'   => '1',
                'options'           => array(
                    1  => esc_html__( 'One', 'divi-machine' ),
                    2  => esc_html__( 'Two', 'divi-machine' ),
                ),
                'depends_show_if' => 'on',
                'computed_affects' => array(
                  '__getarchiveloop',
                ),
                'description'        => esc_html__( 'How many columns do you want to see on mobile', 'divi-machine' ),
            ),
            'button_alignment' => array(
                'label'            => esc_html__( 'Button Alignment', 'et_builder' ),
                'description'      => esc_html__( 'Align your button to the left, right or center of the module.', 'et_builder' ),
                'type'             => 'text_align',
                'option_category'  => 'configuration',
                'options'          => et_builder_get_text_orientation_options( array( 'justified' ) ),
                'tab_slug'         => 'advanced',
                'toggle_slug'      => 'alignment',
            ),
            '__getarchiveloop' => array(
                'type' => 'computed',
                'computed_callback' => array( 'de_mach_archive_loop_code', 'get_archive_loop' ),
                'computed_depends_on' => array(
                  'post_type_choose',
                  'loop_layout',
                  'columns',
                  'columns_tablet',
                  'columns_mobile',
                  'post_status',
                  'posts_number',
                  'include_cats',
                  'include_tags',
                  'acf_name',
                  'acf_value',
                  'sort_order',
                  'order_asc_desc',
                ),
            ),
        );

        return $fields;
    }

    public static function get_archive_loop ( $args = array(), $conditional_tags = array(), $current_page = array() ){
      if (!is_admin()) {
        return;
      }

        ob_start();

        $post_type_choose        = $args['post_type_choose'];
        $loop_layout        = $args['loop_layout'];
        $columns            = $args['columns'];
        $columns_tablet     = $args['columns_tablet'];
        $columns_mobile     = $args['columns_mobile'];

        $post_status     = $args['post_status'];
        $posts_number     = $args['posts_number'];
        $include_cats     = $args['include_cats'];
        $include_tags     = $args['include_tags'];
        $acf_name     = $args['acf_name'];
        $acf_value     = $args['acf_value'];
        $sort_order     = $args['sort_order'];
        $order_asc_desc     = $args['order_asc_desc'];




        $get_cpt_args = array(
          'post_type' => $post_type_choose,
          'post_status' => $post_status,
          'posts_per_page' => $posts_number,
          'orderby' => $sort_order,
          'order' => $order_asc_desc,
      );


      if ($include_cats != "") {
          $get_cpt_args['category_name'] = $include_cats;
      }

      if ($include_tags != "") {
          $get_cpt_args['tag'] = $include_tags;
      }

        query_posts( $get_cpt_args );


        if ($loop_layout == "none") {
            echo "Please create a custom loop layout and specify it in the settings.";
        } else {
        ?>
        <div class="filtered-posts-cont">
            <div class="filtered-posts col-<?php echo $columns?> col-tab-<?php echo $columns_tablet?> col-mob-<?php echo $columns_mobile?>">
        <?php

        if ( have_posts() ) {
          ?>
          <div class="grid-posts loop-grid">
            <?php
          while ( have_posts() ) {
            the_post();

            ?>
            <div class="grid-col">
                <div class="grid-item-cont">
            <?php

        echo apply_filters('the_content', get_post_field('post_content', $loop_layout));

        ?>
        </div>
      </div>
      <?php
                                  }

                    ?>
                  </div>
                  <?php
                  // retrieve the styles for the modules
                  $internal_style = ET_Builder_Element::get_style();
                  // reset all the attributes after we retrieved styles
                  ET_Builder_Element::clean_internal_modules_styles( false );
                  $et_pb_rendering_column_content = false;

                  // append styles
                  if ( $internal_style ) {
              ?>
                  <div class="dmach-inner-styles">
              <?php


              $cleaned_styles = str_replace("#et-boc .et-l","#et-boc .et-l .filtered-posts", $internal_style);
              $cleaned_styles = str_replace(".et_pb_section_",".filtered-posts .et_pb_section_", $cleaned_styles);
              $cleaned_styles = str_replace(".et_pb_row_",".filtered-posts .et_pb_row_", $cleaned_styles);
              $cleaned_styles = str_replace(".et_pb_module_",".filtered-posts .et_pb_module_", $cleaned_styles);
              $cleaned_styles = str_replace(".et_pb_column_",".filtered-posts .et_pb_column_", $cleaned_styles);
              $cleaned_styles = str_replace(".et_pb_de_mach_",".filtered-posts .et_pb_de_mach_", $cleaned_styles);
              $cleaned_styles = str_replace(".filtered-posts .filtered-posts",".filtered-posts", $cleaned_styles);
              $cleaned_styles = str_replace(".filtered-posts .et_pb_section .filtered-posts",".filtered-posts", $cleaned_styles);

              printf(
                  '<style type="text/css" class="dmach_ajax_inner_styles">
                    .filtered-posts .grid-col div.et_pb_section {background-color: transparent;background-image: inherit !important;}
                    %1$s
                  </style>',
                  et_core_esc_previously( $cleaned_styles )
                      );
              ?>
                  </div>
              <?php
                  }

                              }

                              ?>
                              </div>
                            </div>
                            <?php

                          }

        $data = ob_get_clean();

      return $data;

      }

    public function get_button_alignment( $device = 'desktop' ) {
        $suffix           = 'desktop' !== $device ? "_{$device}" : '';
        $text_orientation = isset( $this->props["button_alignment{$suffix}"] ) ? $this->props["button_alignment{$suffix}"] : '';

        return et_pb_get_alignment( $text_orientation );
    }

    function render( $attrs, $content = null, $render_slug ) {

        if (is_admin()) {
            return;
        }

        include(DE_DMACH_PATH . '/titan-framework/titan-framework-embedder.php');
        $titan = TitanFramework::getInstance( 'divi-machine' );
        $enable_debug = $titan->getOption( 'enable_debug' );


        $loop_layout            = $this->props['loop_layout'];
        $post_type_choose       = $this->props['post_type_choose'];
        $post_status            = $this->props['post_status'];
        $include_cats           = $this->props['include_cats'];
        $include_tags           = $this->props['include_tags'];
        // $author       = $this->props['author'];
        $sort_order             = $this->props['sort_order'];
        $order_asc_desc         = $this->props['order_asc_desc'];
        $posts_number           = $this->props['posts_number'];
        $no_posts_layout        = $this->props['no_posts_layout'];


        $columns                = $this->props['columns'];
        $columns_tablet         = $this->props['columns_tablet'];
        $columns_mobile         = $this->props['columns_mobile'];

        $link_whole_gird        = $this->props['link_whole_gird'];

        $acf_name               = $this->props['acf_name'];
        $acf_value              = $this->props['acf_value'];

        $equal_height           = $this->props['equal_height'];
        $align_last_bottom 		= $this->props['align_last_bottom'];

        $grid_layout            = $this->props['grid_layout'];
        $filter_update_animation= $this->props['filter_update_animation'];
        $animation_color        = $this->props['animation_color'];


        $enable_loadmore        = $this->props['enable_loadmore'];
        $loadmore_text          = $this->props['loadmore_text'];
        $loadmore_text_loading  = $this->props['loadmore_text_loading'];

        $button_alignment  = $this->props['button_alignment'];


        $this->add_classname( 'loadmore-align-' . $button_alignment );

        $this->add_classname('grid-layout-' . $grid_layout);

        if ( $equal_height == 'on' ) {
            $this->add_classname('same-height-cards');
        }

        if ( $align_last_bottom == 'on' ) {
            $this->add_classname('align-last-module');
        }

        if ($enable_loadmore == 'on') {
            $this->add_classname('loadmore-enabled');
        }

        if ( '' !== $animation_color ) {
            ET_Builder_Element::set_style( $render_slug, array(
                'selector'    => '%%order_class%% .line',
                'declaration' => sprintf(
                    'background-color: %1$s !important;',
                    esc_html( $animation_color )
                ),
            ) );
        }

        if ( '' !== $animation_color ) {
            ET_Builder_Element::set_style( $render_slug, array(
                'selector'    => '%%order_class%% .donut',
                'declaration' => sprintf(
                    'border-top-color: %1$s !important;',
                    esc_html( $animation_color )
                ),
            ) );
        }

        if ( '' !== $animation_color ) {
            ET_Builder_Element::set_style( $render_slug, array(
                'selector'    => '%%order_class%% .donut.multi',
                'declaration' => sprintf(
                    'border-bottom-color: %1$s !important;',
                    esc_html( $animation_color )
                ),
            ) );
        }

        if ( '' !== $animation_color ) {
            ET_Builder_Element::set_style( $render_slug, array(
                'selector'    => '%%order_class%% .ripple',
                'declaration' => sprintf(
                    'border-color: %1$s !important;',
                    esc_html( $animation_color )
                ),
            ) );
        }

        //////////////////////////////////////////////////////////////////////

        ob_start();

        // $post_link = get_permalink(get_the_ID());

        global $wp_query, $wpdb, $post, $woocommerce;
        $args = array(
            'post_type'         => $post_type_choose,
            'post_status'       => $post_status,
            'posts_per_page'    => (int) $posts_number,
            'orderby'           => $sort_order,
            'order'             => $order_asc_desc
        );

        // Check current page is single post page for selected post type and get current post id
        $current_post = 0;
        if ( $wp_query->is_main_query()
            && $wp_query->is_singular()
            && $wp_query->is_single()
            && $wp_query->query_vars['post_type'] == $post_type_choose ){
            $current_post = $wp_query->post->ID;
        }

        if ( $wp_query->is_main_query()
            && $wp_query->is_archive()
            && !empty( $wp_query->query_vars['taxonomy'] )
            && $wp_query->query_vars['taxonomy'] == $post_type_choose . '_category' ){

            $args['tax_query'] = array(
                array(
                    'taxonomy'  => $wp_query->query_vars['taxonomy'],
                    'field'     => 'slug',
                    'terms'     => $wp_query->query_vars['term']
                )
            );

            $GLOBALS['my_query_filters']['tax_query'] = $post_type_choose . '_category';
        }

        if ( $current_post != 0 ){
            $args['post__not_in'] = array( $current_post );
        }

        if ($include_cats != "") {
            $args['category_name'] = $include_cats;
        }

        if ($include_tags != "") {
            $args['tag'] = $include_tags;
        }

        if ($acf_name != "none") {
            $args['meta_key'] = $acf_name;
        }

        if ($acf_value != "") {
            $acf_value = explode(',', $acf_value);
            $args['meta_value'] = $acf_value;
        }

        // if ($author != "") {
        //   $args['author_name'] = $author;
        // }

        $meta_query = array('relation' => 'AND');

        // loop over filters
        foreach( $GLOBALS['my_query_filters'] as $key => $name ) {

            // continue if not found in url
            if( empty($_GET[ $name ]) ) {
                continue;
            }

            $acf_get = get_field_object($name);
            $acf_type = $acf_get['type'];

            // get the value for this filter
            // eg: http://www.website.com/events?city=melbourne,sydney

                // append meta query
            if ($acf_type == 'range') {

                $value_between = str_replace("%3B",";", $_GET[ $name ]);

                $value = ( explode( ";", $value_between ) );

                if ( sizeof( $value ) == 1 ) {
                    $meta_query[] = array(
                        'key' => $name,
                        'value' => $value[0],
                        'type' => 'NUMERIC',
                        'compare' => '<='
                    );
                }else{
                    $meta_query[] = array(
                        'key' => $name,
                        'value' => $value,
                        'compare' => 'BETWEEN',
                        'type' => 'NUMERIC'
                    );
                }
            } else if ($acf_type == "checkbox") {
                $meta_query[] = array(
                    'key'       => $name,
                    'value'     => $_GET[ $name ],
                    'compare'   => 'LIKE',
                );
            } else {
                $value = explode(',', $_GET[ $name ]);
                $meta_query[] = array(
                    'key'       => $name,
                    'value'     => $value,
                    'compare'   => 'IN',
                );
            }
        }

        if ( !empty( $_GET['s'] ) ){
            $args['s'] = $_GET['s'];
        }

        $args['meta_query'] = $meta_query;

        foreach ( $_GET as $key => $value ) {
            if ( ( $key == $post_type_choose . '_category' ) ||
                 ( $post_type_choose == 'post' && $key == 'category') ){
                if ( $value != 'all' && $value != '' ) {
                    $args['tax_query'] = array(
                        array(
                            'taxonomy'  => $key,
                            'field'     => 'slug',
                            'terms'     => $value
                        )
                    );
                    $GLOBALS['my_query_filters']['tax_query'] = $post_type_choose . '_category';
                }
            }
        }

        $args = apply_filters('dmach_archive_post_args', $args);

        query_posts( $args );

        if ($enable_debug == "1") {
        $acf_get = get_field_object($acf_name);
          ?>
        ?>
      <div class="reporting_args hidethis" style="white-space: pre;">
            <?php  print_r($args); ?>
      </div>
      <?php
    }

        wp_localize_script( 'divi-machine-ajax-loadmore-js', 'divi_machine_loadmore_params', array(
            'ajaxurl' => site_url() . '/wp-admin/admin-ajax.php', // WordPress AJAX
            'posts' => json_encode( $wp_query->query_vars ), // everything about your loop is here
            'current_page' => get_query_var( 'paged' ) ? get_query_var('paged') : 1,
            'max_page' => $wp_query->max_num_pages
        ) );
        wp_enqueue_script( 'divi-machine-ajax-loadmore-js' );

        $get_current_tax = get_query_var('taxonomy');
        $get_current_term = get_query_var( 'term' );

        if ($loop_layout == "none") {
            echo "Please create a custom loop layout and specify it in the settings.";
        } else {
    ?>
              <div class="filtered-posts-cont">
                  <div class="filtered-posts-loading <?php echo $filter_update_animation ?> "></div>
                  <div class="filtered-posts <?php echo $grid_layout ?> col-<?php echo $columns?> col-tab-<?php echo $columns_tablet?> col-mob-<?php echo $columns_mobile?>"
                      data-layoutid="<?php echo $loop_layout ?>"
                      data-posttype="<?php echo $post_type_choose ?>"
                      data-noresults="<?php echo $no_posts_layout ?>"
                      data-sortorder="<?php echo $sort_order ?>"
                      data-sortasc="<?php echo $order_asc_desc ?>"
                      data-gridstyle="<?php echo $grid_layout?>"
                      data-columnscount="<?php echo $columns?>"
                      data-postnumber="<?php echo $posts_number ?>"
                      data-loadmore="<?php echo $enable_loadmore ?>"
                      data-btntext="<?php echo $loadmore_text ?>"
                      data-btntext_loading="<?php echo $loadmore_text_loading ?>"
                      data-posttax=""
                      data-postterm=""
                      data-search="<?php echo get_query_var("s");?>" style="grid-auto-rows: 1px;">
          <?php
            if ( have_posts() ) {
              ?>
              <div class="grid-posts loop-grid"> <?php
                while ( have_posts() ) {
                    the_post();
                    setup_postdata( $post );

                    if ($grid_layout == "masonry") {
    ?>
                <div class="grid-item">
                    <div class="grid-item-cont">
    <?php
                    } else {
    ?>
                <div class="grid-col">
                    <div class="grid-item-cont">
    <?php
                    }

                    if ($link_whole_gird == "on") {
                        echo '<a href="' . $post_link . '">';
                    }

                    // echo do_shortcode('[et_pb_row global_module="' . $loop_layout . '"][/et_pb_row]');
                    echo apply_filters('the_content', get_post_field('post_content', $loop_layout));

                    // $content = apply_filters('the_content', get_post_field('post_content', $loop_layout));

                    // echo et_builder_render_layout($content );

                    if ($link_whole_gird == "on") {
                        echo '</a>';
                    }
    ?>
                    </div>
                </div>
    <?php
                } // end while have posts

                if ($enable_loadmore == "on") {
                    if (  $wp_query->max_num_pages > 1 ){
    ?>
                <div class="dmach-loadmore et_pb_button"><?php echo $loadmore_text ?></div>
    <?php
                    }
                }
    ?>
            </div>
    <?php
            } else {
                if ($no_posts_layout == "none") {
                    echo "No " . $post_type_choose;
                } else {
    ?>
        <div class="no-results-layout">
    <?php
                echo do_shortcode('[et_pb_row global_module="' . $no_posts_layout . '"][/et_pb_row]');
    ?>
        </div>
    <?php
                }
            }
            ?>
            </div>
        </div> <!-- filtered-posts-cont -->
        <?php
        }

        wp_reset_query();

        $data = ob_get_clean();
        //////////////////////////////////////////////////////////////////////
        return $data;
    }
}

new de_mach_archive_loop_code;

?>
